package extensionUpdate.views;

import java.net.MalformedURLException;
import java.net.URL;
import org.eclipse.core.runtime.IExtension;
import org.eclipse.core.runtime.IExtensionPoint;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.jface.viewers.ILabelProviderListener;
import org.eclipse.swt.graphics.Image;
import extensionUpdate.ExtensionUpdatePlugin;

public class ExtensionUpdateLabelProvider implements ILabelProvider {

	public static final String EXTENSION_POINTS = "ExtensionUpdateLabelProvider.extensionpoints.text";
	public static final String EXTENSION_POINT 	= "ExtensionUpdateLabelProvider.extensionpoint.text";
	public static final String EXTENSIONS 		= "ExtensionUpdateLabelProvider.extensions.text";
	public static final String EXTENSION 		= "ExtensionUpdateLabelProvider.extension.text";

	public static final String PLUGIN_IMAGE		= "ExtensionUpdateLabelProvider.plugin.image";
	public static final String PLUGIN_IMAGE_DIS	= "ExtensionUpdateLabelProvider.disabledplugin.image";
	public static final String EXTENSION_POINTS_IMAGE	= "ExtensionUpdateLabelProvider.extensionpoints.image";
	public static final String EXTENSION_POINT_IMAGE	= "ExtensionUpdateLabelProvider.extensionpoint.image";
	public static final String EXTENSIONS_IMAGE	= "ExtensionUpdateLabelProvider.extensions.image";
	public static final String EXTENSION_IMAGE	= "ExtensionUpdateLabelProvider.extension.image";

	public static final URL BASE_URL = ExtensionUpdatePlugin.getDefault().getDescriptor().getInstallURL();

	/**
	 * Constructor for ExtensionUpdateLabelProvider.
	 */
	public ExtensionUpdateLabelProvider() {
	}

	public void dispose() {
	}

	public String getText(Object obj) {
		
		if (obj instanceof IPluginDescriptor)
			return ((IPluginDescriptor)obj).getLabel();
		
		if (obj instanceof IExtensionPoint[])
			if (((IExtensionPoint[])obj).length > 1)
				return ExtensionUpdatePlugin.getResourceString(EXTENSION_POINTS);
			else
				return ExtensionUpdatePlugin.getResourceString(EXTENSION_POINT);
				
		if (obj instanceof IExtension[])
			if (((IExtension[])obj).length > 1)
				return ExtensionUpdatePlugin.getResourceString(EXTENSIONS);
			else
				return ExtensionUpdatePlugin.getResourceString(EXTENSION);
			
		if (obj instanceof IExtensionPoint)
			return ((IExtensionPoint)obj).getLabel();
			
		if (obj instanceof IExtension) {
			String id = ((IExtension)obj).getUniqueIdentifier();
			String text = ((IExtension)obj).getExtensionPointUniqueIdentifier();
			if (id != null && id.length() > 0)
				return text + " (id=" + id + ")";
			return text;
		}
		return "";
	}

	public Image getImage(Object obj) {
		if (obj instanceof IPluginDescriptor) 
			if (((IPluginDescriptor)obj).isPluginActivated())
				return createImage(ExtensionUpdatePlugin.getResourceString(PLUGIN_IMAGE));
			else
				return createImage(ExtensionUpdatePlugin.getResourceString(PLUGIN_IMAGE_DIS));

		if (obj instanceof IExtensionPoint[]) 
			return createImage(ExtensionUpdatePlugin.getResourceString(EXTENSION_POINTS_IMAGE));

		if (obj instanceof IExtensionPoint) 
			return createImage(ExtensionUpdatePlugin.getResourceString(EXTENSION_POINT_IMAGE));

		if (obj instanceof IExtension[]) 
			return createImage(ExtensionUpdatePlugin.getResourceString(EXTENSIONS_IMAGE));

		if (obj instanceof IExtension) 
			return createImage(ExtensionUpdatePlugin.getResourceString(EXTENSION_IMAGE));

		return null;
	}

	public boolean isLabelProperty(Object element, String property) {
		return true;
	}

	public void addListener(ILabelProviderListener listener) {
	}

	public void removeListener(ILabelProviderListener listener) {
	}

	private Image createImage(String path) {
		try {
			URL url	= new URL(BASE_URL, path);
			return ImageDescriptor.createFromURL(url).createImage();
		} catch (MalformedURLException e) {
		}
		return ImageDescriptor.getMissingImageDescriptor().createImage();
	}
}